#
# spec file for package python-django-import-export
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
%define skip_python36 1
Name:           python-django-import-export
Version:        2.7.1
Release:        1.5
Summary:        Django data importing and exporting
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/django-import-export/django-import-export
Source:         https://github.com/django-import-export/django-import-export/archive/%{version}.tar.gz#/django-import-export-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2.0
Requires:       python-diff-match-patch
Requires:       python-tablib >= 0.14.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2.0}
BuildRequires:  %{python_module chardet}
BuildRequires:  %{python_module diff-match-patch}
BuildRequires:  %{python_module tablib >= 0.14.0}
# /SECTION
%python_subpackages

%description
Django application and library for importing and exporting data with included admin integration.

%prep
%setup -q -n django-import-export-%{version}
# Fix postgres specific field
sed -i '/data_field/d' tests/core/migrations/0004_bookwithchapters.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH=${PWD}:${PWD}/tests/
export LANG=en_US.UTF-8
%python_exec -m django test core -v2 --settings=settings

%files %{python_files}
%doc AUTHORS README.rst
%license LICENSE
%{python_sitelib}/*import[-_]export*/

%changelog
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v2.7.1
  * Removed django_extensions from example app settings
  * Added support for Django 4.0
- from v2.7.0
  * Big integer support for Integer widget
  * Added skip_html_diff meta attribute
  * Add ability to rollback the import on validation error
  * Fix crash when deleting via admin site
  * Use Github secret in CI script instead of hard-coded password
  * Documentation: correct error in example application which leads to crash
- from v2.6.1
  * Revert 'dark mode' css: causes issues in django2.2
- from v2.6.0
  * Added guard for null 'options' to fix crash
  * Updated import.css to support dark mode
  * Fixed regression where overridden mixin methods are not called
  * Fix xls/xlsx import of Time fields
  * Added support for 'to_encoding' attribute
  * Fix minor date formatting issue for date with years < 1000
  * Translate the zh_Hans missing part
  * Remove code duplication from mixins.py and admin.py
  * don't test Django main branch with python36,37
  * Support Django 3.2
  * Rephrase logical clauses in docstrings
  * Support multiple databases
  * Add Farsi translated messages in the locale
  * Update Russian translations
  * Append export admin action using ModelAdmin.get_actions
  * CachedInstanceLoader defaults to empty when import_id is missing
  * Add kwargs to import_row, import_object and import_field
  * Call load_workbook() with data_only flag
* Tue May 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Skip python36 build: no pandas.
* Tue Jan 12 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v2.5.0
  * Changed the default value for IMPORT_EXPORT_CHUNK_SIZE to 100
  * Add translation for Korean
  * Update linting, CI, and docs
* Sun Nov 29 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v2.4.0
* Thu Jul 16 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2.3.0
* Wed Apr 22 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2.0.2
